<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div class="container">
 *
 * @package Swimming Pool
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php if ( function_exists( 'wp_body_open' ) ) {
  wp_body_open();
} else {
  do_action( 'wp_body_open' );
} ?>

<div id="preloader">
  <div id="status">&nbsp;</div>
</div>

<a class="screen-reader-text skip-link" href="#content"><?php esc_html_e( 'Skip to content', 'swimming-pool' ); ?></a>

<div class="header">
  <div class="container">
    <div class="row">
      <div class="col-lg-4 col-md-4 col-sm-4 center-align">
        <div class="logo text-center text-md-left py-2 py-md-0">
          <?php swimming_pool_the_custom_logo(); ?>
          <?php $blog_info = get_bloginfo( 'name' ); ?>
          <?php if ( ! empty( $blog_info ) ) : ?>
            <?php if ( get_theme_mod('swimming_pool_title_enable',true) != "") { ?>
            <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"><?php bloginfo('name'); ?></a></h1>
            <?php } ?>
          <?php endif; ?>
        </div>
      </div>
      <div class="col-lg-8 col-md-8 col-sm-8 center-align">
        <div class="row py-0 py-md-3 text-center text-md-left">
          <div class="col-lg-8 col-md-8 col-sm-8 center-align">
            <?php $description = get_bloginfo( 'description', 'display' );
              if ( $description || is_customize_preview() ) : ?>
              <?php if ( get_theme_mod('swimming_pool_tagline_enable',true) != "") { ?>
              <span class="site-description"><?php echo esc_html( $description ); ?></span>
              <?php } ?>
            <?php endif; ?>
          </div>
          <div class="col-lg-4 col-md-4 col-sm-4 center-align social-icons">
            <?php if ( get_theme_mod('swimming_pool_fb_link') != "") { ?>
              <a title="<?php esc_attr('facebook', 'swimming-pool'); ?>" target="_blank" href="<?php echo esc_url(get_theme_mod('swimming_pool_fb_link')); ?>"><i class="fab fa-facebook-square mr-2"></i></a> 
            <?php } ?>
            <?php if ( get_theme_mod('swimming_pool_twitt_link') != "") { ?>
              <a title="<?php esc_attr('twitter', 'swimming-pool'); ?>" target="_blank" href="<?php echo esc_url(get_theme_mod('swimming_pool_twitt_link')); ?>"><i class="fab fa-twitter-square mr-2"></i></a>
            <?php } ?>
            <?php if ( get_theme_mod('swimming_pool_linked_link') != "") { ?>
              <a title="<?php esc_attr('linkedin', 'swimming-pool'); ?>" target="_blank" href="<?php echo esc_url(get_theme_mod('swimming_pool_linked_link')); ?>"><i class="fab fa-linkedin mr-2"></i></a>
            <?php } ?>
            <?php if ( get_theme_mod('swimming_pool_insta_link') != "") { ?>
              <a title="<?php esc_attr('instagram', 'swimming-pool'); ?>" target="_blank" href="<?php echo esc_url(get_theme_mod('swimming_pool_insta_link')); ?>"><i class="fab fa-instagram mr-2"></i></a>
            <?php } ?>
            <?php if ( get_theme_mod('swimming_pool_youtube_link') != "") { ?>
              <a title="<?php esc_attr('youtube', 'swimming-pool'); ?>" target="_blank" href="<?php echo esc_url(get_theme_mod('swimming_pool_youtube_link')); ?>"><i class="fab fa-youtube-square"></i></a>
            <?php } ?>
          </div>
        </div>
        <div class="toggle-nav text-center text-md-right py-2">
          <?php if(has_nav_menu('primary')){ ?>
            <button role="tab"><?php esc_html_e('MENU','swimming-pool'); ?></button>
          <?php }?>
        </div>
        <div id="mySidenav" class="nav sidenav text-right">
          <nav id="site-navigation" class="main-nav" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu','swimming-pool' ); ?>">
            <?php if(has_nav_menu('primary')){
              wp_nav_menu( array( 
                'theme_location' => 'primary',
                'container_class' => 'main-menu clearfix' ,
                'menu_class' => 'clearfix',
                'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
                'fallback_cb' => 'wp_page_menu',
              ) );
            } ?>
            <a href="javascript:void(0)" class="close-button"><?php esc_html_e('CLOSE','swimming-pool'); ?></a>
          </nav>
        </div>        
      </div>
    </div>
  </div>
</div>