<?php
/*
 * @package Swimming Pool
 */

function swimming_pool_admin_enqueue_scripts() {
	wp_enqueue_style( 'swimming-pool-admin-style', esc_url( get_template_directory_uri() ).'/css/addon.css' );
}
add_action( 'admin_enqueue_scripts', 'swimming_pool_admin_enqueue_scripts' );

add_action('after_switch_theme', 'swimming_pool_options');

function swimming_pool_options () {
	global $pagenow;
	if( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) && current_user_can( 'manage_options' ) ) {
		wp_redirect( admin_url( 'themes.php?page=swimming-pool' ) );
		exit;
	}
}

if ( ! defined( 'SWIMMING_POOL_SUPPORT' ) ) {
define('SWIMMING_POOL_SUPPORT',__('https://wordpress.org/support/theme/swimming-pool','swimming-pool'));
}
if ( ! defined( 'SWIMMING_POOL_REVIEW' ) ) {
define('SWIMMING_POOL_REVIEW',__('https://wordpress.org/support/theme/swimming-pool/reviews/#new-post','swimming-pool'));
}
if ( ! defined( 'SWIMMING_POOL_PRO_DEMO' ) ) {
define('SWIMMING_POOL_PRO_DEMO',__('https://www.theclassictemplates.com/demo/swimming-pool/','swimming-pool'));
}
if ( ! defined( 'SWIMMING_POOL_THEME_PAGE' ) ) {
define('SWIMMING_POOL_THEME_PAGE',__('https://www.theclassictemplates.com/themes/','swimming-pool'));
}
if ( ! defined( 'SWIMMING_POOL_PREMIUM_PAGE' ) ) {
define('SWIMMING_POOL_PREMIUM_PAGE',__('https://www.theclassictemplates.com/wp-themes/pool-wordpress-theme/','swimming-pool'));
}

function swimming_pool_theme_info_menu_link() {

	$theme = wp_get_theme();
	add_theme_page(
		sprintf( esc_html__( 'Welcome to %1$s %2$s', 'swimming-pool' ), $theme->display( 'Name' ), $theme->display( 'Version' ) ),
		esc_html__( 'Theme Info', 'swimming-pool' ),'edit_theme_options','swimming-pool','swimming_pool_theme_info_page'
	);
}
add_action( 'admin_menu', 'swimming_pool_theme_info_menu_link' );

function swimming_pool_theme_info_page() {

	$theme = wp_get_theme();
	?>
<div class="wrap theme-info-wrap">
	<h1><?php printf( esc_html__( 'Welcome to %1$s %2$s', 'swimming-pool' ), esc_html($theme->display( 'Name', 'swimming-pool'  )),esc_html($theme->display( 'Version', 'swimming-pool' ))); ?>
	</h1>
	<p class="theme-description">
	<?php esc_html_e( 'Do you want to configure this theme? Look no further, our easy-to-follow theme documentation will walk you through it.', 'swimming-pool' ); ?>
	</p>
	<hr>
	<div class="important-links clearfix">
		<p><strong><?php esc_html_e( 'Theme Links', 'swimming-pool' ); ?>:</strong>
			<a href="<?php echo esc_url( SWIMMING_POOL_THEME_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Theme Page', 'swimming-pool' ); ?></a>
			<a href="<?php echo esc_url( SWIMMING_POOL_SUPPORT ); ?>" target="_blank"><?php esc_html_e( 'Contact Us', 'swimming-pool' ); ?></a>
			<a href="<?php echo esc_url( SWIMMING_POOL_REVIEW ); ?>" target="_blank"><?php esc_html_e( 'Rate This Theme', 'swimming-pool' ); ?></a>
			<a href="<?php echo esc_url( SWIMMING_POOL_PRO_DEMO ); ?>" target="_blank"><?php esc_html_e( 'Premium Demo', 'swimming-pool' ); ?></a>
			<a href="<?php echo esc_url( SWIMMING_POOL_PREMIUM_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Go To Premium', 'swimming-pool' ); ?></a>
		</p>
	</div>
	<hr>
	<div id="getting-started">
		<h3><?php printf( esc_html__( 'Getting started with %s', 'swimming-pool' ),
		esc_html($theme->display( 'Name', 'swimming-pool' ))); ?></h3>
		<div class="columns-wrapper clearfix">
			<div class="column column-half clearfix">
				<div class="section">
					<h4><?php esc_html_e( 'Theme Description', 'swimming-pool' ); ?></h4>
					<div class="theme-description-1"><?php echo esc_html($theme->display( 'Description' )); ?></div>
				</div>
			</div>
			<div class="column column-half clearfix">
				<img src="<?php echo esc_url( $theme->get_screenshot() ); ?>" />
				<div class="section">
					<h4><?php esc_html_e( 'Theme Options', 'swimming-pool' ); ?></h4>
					<p class="about">
					<?php printf( esc_html__( '%s makes use of the Customizer for all theme settings. Click on "Customize Theme" to open the Customizer now.', 'swimming-pool' ),esc_html($theme->display( 'Name', 'swimming-pool' ))); ?></p>
					<p>
					<a href="<?php echo esc_attr(wp_customize_url()); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Customize Theme', 'swimming-pool' ); ?></a>
					<a href="<?php echo esc_url( SWIMMING_POOL_PREMIUM_PAGE ); ?>" target="_blank" class="button button-secondary premium-btn"><?php esc_html_e( 'Checkout Premium', 'swimming-pool' ); ?></a></p>
				</div>
			</div>
		</div>
	</div>
	<hr>
	<div id="theme-author">
	  <p><?php
		printf( esc_html__( '%1$s is proudly brought to you by %2$s. If you like this theme, %3$s :)', 'swimming-pool' ),
			esc_html($theme->display( 'Name', 'swimming-pool' )),
			'<a target="_blank" href="' . esc_url( 'https://www.theclassictemplates.com/', 'swimming-pool' ) . '">classictemplate</a>',
			'<a target="_blank" href="' . esc_url( SWIMMING_POOL_REVIEW ) . '" title="' . esc_attr__( 'Rate it', 'swimming-pool' ) . '">' . esc_html_x( 'rate it', 'If you like this theme, rate it', 'swimming-pool' ) . '</a>'
		)
		?></p>
	</div>
</div>
<?php
}
