<?php
/**
 * @package Swimming Pool
 * Setup the WordPress core custom header feature.
 *
 * @uses swimming_pool_header_style()
 */
function swimming_pool_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'swimming_pool_custom_header_args', array(
		'default-text-color'     => 'fff',
		'width'                  => 2500,
		'height'                 => 400,
		'wp-head-callback'       => 'swimming_pool_header_style',
	) ) );
}
add_action( 'after_setup_theme', 'swimming_pool_custom_header_setup' );

if ( ! function_exists( 'swimming_pool_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see swimming_pool_custom_header_setup().
 */
function swimming_pool_header_style() {
	$header_text_color = get_header_textcolor();

	?>
	<style type="text/css">
	<?php
		//Check if user has defined any header image.
		if ( get_header_image() || get_header_textcolor() ) :
	?>
		.header-image {
			background: url(<?php echo esc_url( get_header_image() ); ?>) no-repeat;
			background-position: center top;
			background-size: cover;
			height:400px;
		}

	<?php endif; ?>	

	h1.site-title a {
		color: <?php echo esc_attr(get_theme_mod('swimming_sitetitle_color')); ?>;
	}

	span.site-description {
		color: <?php echo esc_attr(get_theme_mod('swimming_sitetagline_color')); ?>;
	}

	.social-icons .fa-facebook-square {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_fb_color')); ?>;
	}

	.social-icons .fa-twitter-square {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_twitt_color')); ?>;
	}

	.social-icons .fa-linkedin  {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_linked_color')); ?>;
	}

	.social-icons .fa-instagram  {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_insta_color')); ?>;
	}

	.social-icons .fa-youtube-square {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_youtube_color')); ?>;
	}

	.page-template-template-home-page .header {
        background: linear-gradient(0deg,<?php echo esc_attr(get_theme_mod('swimming_pool_bg_color1')); ?>,<?php echo esc_attr(get_theme_mod('swimming_pool_bg_color2')); ?> 80%) no-repeat;
	}

	.main-nav a {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_menu_color')); ?>;
	}

	.main-menu {
		background: <?php echo esc_attr(get_theme_mod('swimming_pool_menubg_color')); ?>;
		border-color: <?php echo esc_attr(get_theme_mod('swimming_pool_menubg_color')); ?>;

	}

	.main-nav a:hover, .current_page_item a {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_menuhrv_color')); ?>;
	}


	.main-nav ul ul a{
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_submenu_color')); ?>;
	}

	.main-nav ul ul {
		background: <?php echo esc_attr(get_theme_mod('swimming_pool_submenubg_color')); ?>;
	}

	.main-nav ul ul a:hover {
		color: <?php echo esc_attr(get_theme_mod('swimming_pool_submenuhrv_color')); ?>;
	}

	.main-nav ul ul:hover {
		background: <?php echo esc_attr(get_theme_mod('swimming_pool_submenubghrv_color')); ?>;
	}




	.slider-box h3 {
		color: <?php echo esc_attr(get_theme_mod('swimming_slidertitle_color')); ?>;
	}

	.slider-box p {
		color: <?php echo esc_attr(get_theme_mod('swimming_sliderdescription_color')); ?>;
	}

	.slide-btn a {
		color: <?php echo esc_attr(get_theme_mod('swimming_sliderbuttontext_color')); ?>;
	}

	.slide-btn a {
		border-color: <?php echo esc_attr(get_theme_mod('swimming_sliderbuttonborder_color')); ?>;
	}

	.slide-btn a:hover {
	    background: linear-gradient(0deg,<?php echo esc_attr(get_theme_mod('swimming_sliderbuttonhvr_color1')); ?>,<?php echo esc_attr(get_theme_mod('swimming_sliderbuttonhvr_color2')); ?> 80%) no-repeat;
	}



	.odd-even:nth-child(even) {
		background: <?php echo esc_attr(get_theme_mod('swimming_servicebg_coloreven')); ?>;
	}

	.odd-even:nth-child(odd) {
		background: <?php echo esc_attr(get_theme_mod('swimming_servicebg_colorodd')); ?>;
	}

	.services_inner_box h4 a {
		color: <?php echo esc_attr(get_theme_mod('swimming_servicetitle_color')); ?>;
	}

	.services_inner_box p {
		color: <?php echo esc_attr(get_theme_mod('swimming_servicedescription_color')); ?>;
	}

	.service-btn a {
		background: <?php echo esc_attr(get_theme_mod('swimming_servicebutton_color')); ?>;
	}

	.service-btn a {
		color: <?php echo esc_attr(get_theme_mod('swimming_servicebuttontext_color')); ?>;
	}




	.copywrap a {
		color: <?php echo esc_attr(get_theme_mod('swimming_footercoypright_color')); ?>;
	}

	.ftr-4-box ul li a, .ftr-4-box a {

	}

	.ftr-4-box h3, .ftr-4-box h2 {
		color: <?php echo esc_attr(get_theme_mod('swimming_footertitle_color')); ?>;

	}

	.ftr-4-box p {
		color: <?php echo esc_attr(get_theme_mod('swimming_footerdescription_color')); ?>;

	}

	.copywrap a:hover, .ftr-4-box ul li a:hover {
		color: <?php echo esc_attr(get_theme_mod('swimming_footertexthover_color')); ?>;

	}

	#footer {
		background-color: <?php echo esc_attr(get_theme_mod('swimming_footerbg_color')); ?>;
	}
	

	</style>
	<?php 
}
endif;