<?php
/**
 * Swimming Pool Theme Customizer
 *
 * @package Swimming Pool
 */

get_template_part('/inc/select/category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function swimming_pool_customize_register( $wp_customize ) {

	function swimming_pool_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';


	// color site title
	$wp_customize->add_setting('swimming_sitetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sitetitle_color', array(
	   'settings' => 'swimming_sitetitle_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Title Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('swimming_pool_title_enable',array(
		'default' => true,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
	));
	$wp_customize->add_control( 'swimming_pool_title_enable', array(
	   'settings' => 'swimming_pool_title_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Title','swimming-pool'),
	   'type'      => 'checkbox'
	));



	// color site tagline
	$wp_customize->add_setting('swimming_sitetagline_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sitetagline_color', array(
	   'settings' => 'swimming_sitetagline_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Tagline Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('swimming_pool_tagline_enable',array(
		'default' => true,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
	));
	$wp_customize->add_control( 'swimming_pool_tagline_enable', array(
	   'settings' => 'swimming_pool_tagline_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Tagline','swimming-pool'),
	   'type'      => 'checkbox'
	));





	//Theme Options
	$wp_customize->add_panel( 'swimming_pool_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'swimming-pool' ),
	) );
	
	// Header Section
	$wp_customize->add_section('swimming_pool_header_section', array(
        'title' => __('Header Section', 'swimming-pool'),
        'priority' => null,
		'panel' => 'swimming_pool_panel_area',
 	));


 	// bg color 1
	$wp_customize->add_setting('swimming_pool_bg_color1',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_bg_color1', array(
	   'settings' => 'swimming_pool_bg_color1',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('BG Color 1', 'swimming-pool'),
	   'type'      => 'color'
	));

	// bg color 2
	$wp_customize->add_setting('swimming_pool_bg_color2',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_bg_color2', array(
	   'settings' => 'swimming_pool_bg_color2',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('BG Color 2', 'swimming-pool'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('swimming_pool_fb_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_fb_link', array(
	   'settings' => 'swimming_pool_fb_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Facebook Link', 'swimming-pool'),
	   'type'      => 'url'
	));


	// color facebook
	$wp_customize->add_setting('swimming_pool_fb_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_fb_color', array(
	   'settings' => 'swimming_pool_fb_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Facebook Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('swimming_pool_twitt_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_twitt_link', array(
	   'settings' => 'swimming_pool_twitt_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Twitter Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	// color twitt
	$wp_customize->add_setting('swimming_pool_twitt_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_twitt_color', array(
	   'settings' => 'swimming_pool_twitt_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Twitter Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('swimming_pool_linked_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_linked_link', array(
	   'settings' => 'swimming_pool_linked_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Linkdin Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	// color linked
	$wp_customize->add_setting('swimming_pool_linked_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_linked_color', array(
	   'settings' => 'swimming_pool_linked_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Linked Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('swimming_pool_insta_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_insta_link', array(
	   'settings' => 'swimming_pool_insta_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Instagram Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	// color insta
	$wp_customize->add_setting('swimming_pool_insta_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_insta_color', array(
	   'settings' => 'swimming_pool_insta_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Instagram Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('swimming_pool_youtube_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_youtube_link', array(
	   'settings' => 'swimming_pool_youtube_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Youtube Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	// color youtube
	$wp_customize->add_setting('swimming_pool_youtube_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_youtube_color', array(
	   'settings' => 'swimming_pool_youtube_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Youtube Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	// header menu
	$wp_customize->add_setting('swimming_pool_menu_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_menu_color', array(
	   'settings' => 'swimming_pool_menu_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Menu Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// header menu bg
	$wp_customize->add_setting('swimming_pool_menubg_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_menubg_color', array(
	   'settings' => 'swimming_pool_menubg_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Menu BG Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// header menu hover color
	$wp_customize->add_setting('swimming_pool_menuhrv_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_menuhrv_color', array(
	   'settings' => 'swimming_pool_menuhrv_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Menu Active & Hover Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// header sub menu color
	$wp_customize->add_setting('swimming_pool_submenu_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_submenu_color', array(
	   'settings' => 'swimming_pool_submenu_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('SubMenu Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// header sub menu bg color
	$wp_customize->add_setting('swimming_pool_submenubg_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_submenubg_color', array(
	   'settings' => 'swimming_pool_submenubg_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('SubMenu BG Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// header sub menu hover color
	$wp_customize->add_setting('swimming_pool_submenuhrv_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_submenuhrv_color', array(
	   'settings' => 'swimming_pool_submenuhrv_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('SubMenu Hover Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// header sub menu bg hover color
	$wp_customize->add_setting('swimming_pool_submenubghrv_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_pool_submenubghrv_color', array(
	   'settings' => 'swimming_pool_submenubghrv_color',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('SubMenu BG Hover Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	// Home Category Dropdown Section
	$wp_customize->add_section('swimming_pool_one_cols_section',array(
		'title'	=> __('Slider','swimming-pool'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1600 x 850).','swimming-pool'),
		'priority'	=> null,
		'panel' => 'swimming_pool_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'swimming_pool_slidersection', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Swimming_Pool_Category_Dropdown_Custom_Control( $wp_customize, 'swimming_pool_slidersection', array(
		'section' => 'swimming_pool_one_cols_section',
		'settings'   => 'swimming_pool_slidersection',
	) ) );

	//Hide Section
	$wp_customize->add_setting('swimming_pool_hide_categorysec',array(
		'default' => false,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'swimming_pool_hide_categorysec', array(
	   'settings' => 'swimming_pool_hide_categorysec',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label'     => __('Check To Enable This Section','swimming-pool'),
	   'type'      => 'checkbox'
	));

	$wp_customize->add_setting('swimming_pool_button_text',array(
		'default' => 'CONTACT US',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_button_text', array(
	   'settings' => 'swimming_pool_button_text',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Add Button Text', 'swimming-pool'),
	   'type'      => 'text'
	));


	// color slider title
	$wp_customize->add_setting('swimming_slidertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_slidertitle_color', array(
	   'settings' => 'swimming_slidertitle_color',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Title Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	// color slider description
	$wp_customize->add_setting('swimming_sliderdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sliderdescription_color', array(
	   'settings' => 'swimming_sliderdescription_color',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Description Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	// color slider button text
	$wp_customize->add_setting('swimming_sliderbuttontext_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sliderbuttontext_color', array(
	   'settings' => 'swimming_sliderbuttontext_color',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Button Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	// color slider button border
	$wp_customize->add_setting('swimming_sliderbuttonborder_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sliderbuttonborder_color', array(
	   'settings' => 'swimming_sliderbuttonborder_color',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Button Border Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	// color slider button hover 1
	$wp_customize->add_setting('swimming_sliderbuttonhvr_color1',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sliderbuttonhvr_color1', array(
	   'settings' => 'swimming_sliderbuttonhvr_color1',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Button Hover Color 1', 'swimming-pool'),
	   'type'      => 'color'
	));

	// color slider button hover 2
	$wp_customize->add_setting('swimming_sliderbuttonhvr_color2',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_sliderbuttonhvr_color2', array(
	   'settings' => 'swimming_sliderbuttonhvr_color2',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Button Hover Color 2', 'swimming-pool'),
	   'type'      => 'color'
	));


	
	
	// Services Section 
	$wp_customize->add_section('swimming_pool_below_slider_section', array(
		'title'	=> __('Services Section','swimming-pool'),
		'description'	=> __('Select Pages from the dropdown for Services.','swimming-pool'),
		'priority'	=> null,
		'panel' => 'swimming_pool_panel_area',
	));

	
	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'swimming_pool_services_cat', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Swimming_Pool_Category_Dropdown_Custom_Control( $wp_customize, 'swimming_pool_services_cat', array(
		'section' => 'swimming_pool_below_slider_section',
		'settings'   => 'swimming_pool_services_cat',
	) ) );

	$wp_customize->add_setting('swimming_pool_disabled_pgboxes',array(
		'default' => false,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	
	$wp_customize->add_control( 'swimming_pool_disabled_pgboxes', array(
	   'settings' => 'swimming_pool_disabled_pgboxes',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label'     => __('Check To Enable This Section','swimming-pool'),
	   'type'      => 'checkbox'
	));


	//  service bg color odd
	$wp_customize->add_setting('swimming_servicebg_colorodd',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_servicebg_colorodd', array(
	   'settings' => 'swimming_servicebg_colorodd',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('BG Color Odd', 'swimming-pool'),
	   'type'      => 'color'
	));

	//  service bg color even
	$wp_customize->add_setting('swimming_servicebg_coloreven',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_servicebg_coloreven', array(
	   'settings' => 'swimming_servicebg_coloreven',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('BG Color Even', 'swimming-pool'),
	   'type'      => 'color'
	));


	

	//  service title color 
	$wp_customize->add_setting('swimming_servicetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_servicetitle_color', array(
	   'settings' => 'swimming_servicetitle_color',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Title Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	//  service description color 
	$wp_customize->add_setting('swimming_servicedescription_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_servicedescription_color', array(
	   'settings' => 'swimming_servicedescription_color',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Description Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	//  service button color 
	$wp_customize->add_setting('swimming_servicebutton_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_servicebutton_color', array(
	   'settings' => 'swimming_servicebutton_color',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Button Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	//  service button text color 
	$wp_customize->add_setting('swimming_servicebuttontext_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_servicebuttontext_color', array(
	   'settings' => 'swimming_servicebuttontext_color',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Button Text Color', 'swimming-pool'),
	   'type'      => 'color'
	));




	// Footer Section 
	$wp_customize->add_section('swimming_pool_footer', array(
		'title'	=> __('Footer Section','swimming-pool'),
		'priority'	=> null,
		'panel' => 'swimming_pool_panel_area',
	));

	$wp_customize->add_setting('swimming_pool_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'swimming_pool_copyright_line', array(
	   'section' 	=> 'swimming_pool_footer',
	   'label'	 	=> __('Copyright Line','swimming-pool'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));


	//  footer coypright color 
	$wp_customize->add_setting('swimming_footercoypright_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_footercoypright_color', array(
	   'settings' => 'swimming_footercoypright_color',
	   'section'   => 'swimming_pool_footer',
	   'label' => __('Coypright Color', 'swimming-pool'),
	   'type'      => 'color'
	));



	//  footer bg color 
	$wp_customize->add_setting('swimming_footerbg_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_footerbg_color', array(
	   'settings' => 'swimming_footerbg_color',
	   'section'   => 'swimming_pool_footer',
	   'label' => __('BG Color', 'swimming-pool'),
	   'type'      => 'color'
	));


	//  footer title color 
	$wp_customize->add_setting('swimming_footertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_footertitle_color', array(
	   'settings' => 'swimming_footertitle_color',
	   'section'   => 'swimming_pool_footer',
	   'label' => __('Title Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	//  footer description color 
	$wp_customize->add_setting('swimming_footerdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_footerdescription_color', array(
	   'settings' => 'swimming_footerdescription_color',
	   'section'   => 'swimming_pool_footer',
	   'label' => __('Description Color', 'swimming-pool'),
	   'type'      => 'color'
	));

	//  footer texthover color 
	$wp_customize->add_setting('swimming_footertexthover_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'swimming_footertexthover_color', array(
	   'settings' => 'swimming_footertexthover_color',
	   'section'   => 'swimming_pool_footer',
	   'label' => __('Text Hover Color', 'swimming-pool'),
	   'type'      => 'color'
	));



}
add_action( 'customize_register', 'swimming_pool_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function swimming_pool_customize_preview_js() {
	wp_enqueue_script( 'swimming_pool_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'swimming_pool_customize_preview_js' );